@@ -7,15 +7,15 @@ from pythonbible import Book
 
 DIGIT: str = r"(\d{1,3})"
 SPACE: str = r"\s*"
-COLON: str = rf"{SPACE}([:.]){SPACE}"
-DASH = rf"{SPACE}-{SPACE}"
-COMMA = rf"{SPACE},{SPACE}"
+COLON: str = f"{SPACE}([:.]){SPACE}"
+DASH = f"{SPACE}-{SPACE}"
+COMMA = f"{SPACE},{SPACE}"
 
 BOOK: str = rf"\b({'|'.join(book.regular_expression for book in Book)})\b\.*"
 CHAPTER: str = DIGIT
 VERSE: str = DIGIT
 
-CHAPTER_AND_VERSE: str = rf"({CHAPTER}(?:{COLON}{VERSE})?)"
+CHAPTER_AND_VERSE: str = f"({CHAPTER}(?:{COLON}{VERSE})?)"
 
 # Possibly range regular expressions are:
 # 1. Book - Book (with optional chapter/verse)
@@ -27,15 +27,15 @@ CHAPTER_AND_VERSE: str = rf"({CHAPTER}(?:{COLON}{VERSE})?)"
 
 # TODO - this regex may have some false positives for ranges given the above rules.
 RANGE: str = (
-    rf"{DASH}(({BOOK}{SPACE}(?:{CHAPTER_AND_VERSE})?)|{CHAPTER_AND_VERSE}|{VERSE})"
+    f"{DASH}(({BOOK}{SPACE}(?:{CHAPTER_AND_VERSE})?)|{CHAPTER_AND_VERSE}|{VERSE})"
 )
 
-ADDITIONAL_REFERENCE: str = rf"({COMMA}({CHAPTER_AND_VERSE}(?:{RANGE})?|{VERSE}))"
+ADDITIONAL_REFERENCE: str = f"({COMMA}({CHAPTER_AND_VERSE}(?:{RANGE})?|{VERSE}))"
 FULL_CHAPTER_AND_VERSE: str = (
     f"({CHAPTER_AND_VERSE}(?:{RANGE})?({ADDITIONAL_REFERENCE})*)"
 )
-FULL_BOOK = rf"({BOOK}){SPACE}(?:{FULL_CHAPTER_AND_VERSE})?"
-CROSS_BOOK = rf"({FULL_BOOK}(?:{DASH}({FULL_BOOK}))?)"
+FULL_BOOK = f"({BOOK}){SPACE}(?:{FULL_CHAPTER_AND_VERSE})?"
+CROSS_BOOK = f"({FULL_BOOK}(?:{DASH}({FULL_BOOK}))?)"
 
 SCRIPTURE_REFERENCE_REGULAR_EXPRESSION: Pattern[str] = re.compile(
     CROSS_BOOK,
